"use client";

import changePassword from "@/actions/changePassword";
import Input from "@/components/Input";
import PrettyForm from "@/components/PrettyForm";
import { PasswordUpdateSchema, passwordUpdateSchema } from "@/schemas";
import { Form, Formik, FormikHelpers } from "formik";
import { useRouter } from "next/navigation";
import React from "react";
import { toFormikValidationSchema } from "zod-formik-adapter";

export default function ChangePasswordForm({
  onSuccess
}: {
  onSuccess?: () => void;
}) {
  const [globalError, setGlobalError] = React.useState<string | null>(null);
  const router = useRouter();

  const initialValues: PasswordUpdateSchema = {
    password: "",
    newPassword: "",
    confirmPassword: ""
  };

  async function handleFormSubmit(
    data: PasswordUpdateSchema,
    helpers: FormikHelpers<PasswordUpdateSchema>
  ) {
    helpers.setSubmitting(true);
    setGlobalError(null);
    const res = await changePassword(data);

    if (!res.ok) {
      setGlobalError(res.error!); // should probably make this more human readable :trolley:
    } else {
      if (onSuccess == null) {
        console.log("changed password :3");
        router.push("/me");
      } else {
        onSuccess();
      }
    }

    helpers.setSubmitting(false);
  }

  return (
    <>
      <PrettyForm globalError={globalError}>
        <Formik
          initialValues={initialValues}
          onSubmit={handleFormSubmit}
          validationSchema={toFormikValidationSchema(passwordUpdateSchema)}
        >
          {({ isSubmitting }) => (
            <Form>
              <Input type="password" name="password" label="Current Password" />
              <Input type="password" name="newPassword" label="New Password" />
              <Input
                type="password"
                name="confirmPassword"
                label="Confirm New Password"
                hint="Re-enter your new password. Better safe than sorry!"
              />

              <button type="submit" disabled={isSubmitting}>
                Change Password
              </button>
            </Form>
          )}
        </Formik>
      </PrettyForm>
    </>
  );
}
